#
# spec file for package xpra
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012-2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if ! %{defined _fillupdir}
%define _fillupdir /var/adm/fillup-templates
%endif
%global __requires_exclude ^typelib\\(GtkosxApplication\\)|typelib\\(GdkGLExt\\)|typelib\\(GtkGLExt\\).*$
Name:           xpra
Version:        2.5.3
Release:        4.2
Summary:        Remote display server for applications and desktops
License:        GPL-2.0-or-later AND BSD-3-Clause AND LGPL-3.0-or-later AND MIT
Group:          Productivity/Networking/Other
URL:            https://www.xpra.org/
Source0:        https://xpra.org/src/%{name}-%{version}.tar.xz
Source1:        xpra-icon.png
# PATCH-FIX-OPENSUSE xpra-paths.patch -- use suse-specific paths
Patch0:         %{name}-paths.patch
BuildRequires:  ImageMagick
BuildRequires:  brotli
BuildRequires:  cups
BuildRequires:  cups-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  python-Cython >= 0.20.0
BuildRequires:  python-gobject-devel
BuildRequires:  python2-devel
BuildRequires:  systemd
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libavcodec) >= 57
BuildRequires:  pkgconfig(libavformat) >= 57
BuildRequires:  pkgconfig(libswscale) >= 4
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libwebp) >= 0.4
BuildRequires:  pkgconfig(pycairo)
BuildRequires:  pkgconfig(pygtk-2.0)
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(vpx) >= 1.4.0
%endif
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xtst)
Requires:       dbus-1-python
Requires:       dbus-1-x11
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       pulseaudio
Requires:       pulseaudio-utils
Requires:       python2-Pillow
Requires:       python2-gst
Requires:       python2-lz4
Requires:       python2-numpy
Requires:       python2-opencv
Requires:       python2-pycups
Requires:       python2-rencode
Requires:       shared-mime-info
Requires:       xf86-video-dummy
Requires:       xorg-x11-xauth
Requires(post): %fillup_prereq
Recommends:     python2-dnspython
Recommends:     python2-opencv
Recommends:     python2-paramiko
%{?systemd_requires}

%description
Xpra is "screen for X": it allows you to run X programs, usually on a remote
host, direct their display to your local machine, and then to disconnect from
these programs and reconnect from the same or another machine, without losing
any state. It gives you remote access to individual applications.

Xpra is "rootless" or "seamless": programs you run under it show up on your
desktop as regular programs, managed by your regular window manager.
Sessions can be accessed over SSH, or password protected over plain TCP sockets.
Xpra is usable over reasonably slow links and does its best to adapt to changing
network bandwidth constraints.

%package        html5
Summary:        HTML5 server and client support for xpra
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}
# websockify is required to allow xpra to listen for an html5 client
Requires:       python2-websockify
Provides:       bundled(js-aurora)
Provides:       bundled(js-bencode)
Provides:       bundled(js-broadway)
Provides:       bundled(js-forge)
Provides:       bundled(js-jquery) = 3.1.1
Provides:       bundled(js-jquery-ui) = 1.12.1
Provides:       bundled(js-lz4)
Provides:       bundled(js-zlib)
BuildArch:      noarch

%description    html5
This package adds websockify support to allow xpra to listen for http
connections, and also the xpra html5 client.

%prep
%setup -q
%patch0 -p1
# fix shebangs
find -name '*.py' \
     -exec sed -i '1{\@^#!/usr/bin/env python@d}' {} +
sed -i "1 s|^#!/usr/bin/env python\b|#!%__python2|" cups/xpraforwarder
# fix python-bytecode-inconsistent-mtime warning
find . -name '*.py' -exec touch -mat 1707141200 {} +
install -m0644 %{SOURCE1} -t xdg
# set fillup dir
sed -e 's|__FILLUPDIR__|%{_fillupdir}|' \
    -e 's|__UNITDIR__|%{_unitdir}|' \
    -i setup.py
# fix shebang
sed -i 's|^#!.*|#!%__python2|' scripts/auth_dialog scripts/xdg-open

%build
python2 setup.py build \
    --verbose \
%if 0%{?suse_version} > 1500
    --with-enc_ffmpeg \
    --with-vpx \
%endif
%if 0%{?suse_version} == 1500
    --with-vpx \
    --without-enc_ffmpeg \
%endif
%if 0%{?suse_version} < 1500
    --without-vpx \
    --without-enc_ffmpeg \
%endif
    --with-dec_avcodec2 \
    --with-csc_swscale \
    --with-webp \
    --with-Xdummy \
    --with-Xdummy_wrapper \
    --with-opengl \
    --with-service

%install
python2 setup.py install \
    --skip-build \
    --root %{buildroot} \
    --prefix /usr \
    --verbose

#Install nvenc.keys file
mkdir -p %{buildroot}%{_sysconfdir}/xpra
install -pm 644 etc/xpra/nvenc.keys %{buildroot}%{_sysconfdir}/xpra

# Ensure all .js files are not executable
find %{buildroot}%{_datadir}/xpra/www/js -name '*.js' \
    -exec chmod 0644 {} +

%suse_update_desktop_file -r xpra Network RemoteAccess
%suse_update_desktop_file -r xpra-gui Network RemoteAccess
%suse_update_desktop_file -r xpra-launcher Network RemoteAccess

mkdir -pv %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%fdupes -s %{buildroot}

%pre
getent group xpra >/dev/null || groupadd -r xpra
mkdir -p %{_rundir}/%{name} || exit 1
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%fillup_only %{name}
%tmpfiles_create %{_tmpfilesdir}/xpra.conf

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc README NEWS
%license COPYING
%dir %{_datadir}/xpra
%dir %{_datadir}/xpra/content-categories
%dir %{_datadir}/xpra/content-type
%dir %{_datadir}/xpra/http-headers
%dir %{_libexecdir}/xpra
%dir %{_sysconfdir}/pam.d
%dir %{_sysconfdir}/xpra
%dir %{_sysconfdir}/xpra/conf.d
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/xpra.conf
%config(noreplace) %{_sysconfdir}/pam.d/xpra
%config(noreplace) %{_sysconfdir}/xpra/*.conf
%config(noreplace) %{_sysconfdir}/xpra/nvenc.keys
%config(noreplace) %{_sysconfdir}/xpra/conf.d/*.conf
%config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/90-xpra-virtual.conf
%{_fillupdir}/sysconfig.%{name}
%{_bindir}/xpra
%{_bindir}/xpra_Xdummy
%{_bindir}/xpra_launcher
%{_bindir}/xpra_signal_listener
%{_bindir}/xpra_udev_product_version
%{_libexecdir}/udev/rules.d/71-xpra-virtual-pointer.rules
%{_libexecdir}/xpra/auth_dialog
%{_libexecdir}/xpra/gnome-open
%{_libexecdir}/xpra/gvfs-open
%{_libexecdir}/xpra/xdg-open
%{_sbindir}/rc%{name}
%{python_sitearch}/xpra
%{python_sitearch}/%{name}-%{version}-py%{python_version}.egg-info
%{_datadir}/appdata/xpra.appdata.xml
%{_datadir}/applications/xpra-gui.desktop
%{_datadir}/applications/xpra-launcher.desktop
%{_datadir}/applications/xpra-shadow.desktop
%{_datadir}/applications/xpra.desktop
%{_datadir}/pixmaps/xpra-mdns.png
%{_datadir}/pixmaps/xpra-shadow.png
%{_datadir}/pixmaps/xpra.png
%{_datadir}/mime/packages/application-x-xpraconfig.xml
%{_datadir}/xpra/bell.wav
%{_datadir}/xpra/content-categories/10_default.conf
%{_datadir}/xpra/content-type/10_role.conf
%{_datadir}/xpra/content-type/30_title.conf
%{_datadir}/xpra/content-type/50_class.conf
%{_datadir}/xpra/content-type/70_commands.conf
%{_datadir}/xpra/http-headers/00_nocache.txt
%{_datadir}/xpra/http-headers/10_content_security_policy.txt
%{_datadir}/xpra/icons
%{_libexecdir}/cups/backend/xpraforwarder
%{_mandir}/man1/xpra.1%{?ext_man}
%{_mandir}/man1/xpra_launcher.1%{?ext_man}
%{_sysusersdir}/xpra.conf
%{_tmpfilesdir}/xpra.conf
%{_unitdir}/xpra.service
%{_unitdir}/xpra.socket
%ghost %dir %{_rundir}/xpra

%files html5
%{_datadir}/xpra/www

%changelog
* Sat Jul 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5.3
  * fix HTML5 MSIE 11 detection
  * fix HTML5 path of audio script for IE
  * fix HTML5 CapsLock and NumLock state detection
  * fix HTML5 desktop server screen size not resizing to match
    window
  * fix shadow servers display resizing not being propagated
  * fix scroll encoding with multi monitor shadow servers
  * fix handling of uncompressed window icon pixel data
  * fix handling of unicode values for desktop names
  * fix remote ssh failures with python3-only installations
  * fix '_monitor' subcommand with python3 clients
  * fix client ping latency calculations
  * fix non-strict ssl host key not honoured with wss connections
  * fix handling of websocket and ssl traffic with unix-domain
    sockets
  * fix ssl and websocket connection upgrades with python3
    servers
  * fix handling of websocket ping packets
  * fix unnecessary delay in initial connection handling
  * fix incorrect disconnections with non-UI clients
  * fix spurious socket warnings
  * fix distro information shown for proxied connections
  * fix invalid mdns records for rfb connections (desktop and
    shadow servers)
  * fix GTK3 signal handling before the main loop is running
  * fix file descriptor leak when running child commands
  * fix clipboard-direction setting not propagated to the client
  * fix clipboard datatype shortcut not taken due to a typo
  * fix clipboard bugs with python3 builds, invalid atoms
  * fix overzealous cleanup code in X11 root property handler
  * fix Xresources debug logging and error handler
  * fix errors during cleanup: close display later
  * fix uinput device mode with python3 servers
  * fix errors if md5 is not available: use sha1
  * fix default build options for RedHat
  * fix typos in man page and docstrings
  * silence annoying atk warnings
  * avoid running invalid lpinfo commands
  * improve compatibility with 'xpra top'
  * make it possible to skip opengl probing during server startup
  * add missing modal-window entry in man page
  * reduce weak RPM dependencies on gnome components
* Fri Jun 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5.2
  * fix mmap leak which can cause the client to stop painting
  * fix OpenGL crashes: don't try to use it when probing process
    has crashed
  * fix errors in avahi error handler
  * fix connection errors when loading ssh public keys
  * fix tests being run with the wrong python interpreter version
  * fix systemd-run using the wrong python interpreter version
  * fix start menu with python3 clients
  * fix x264 encoder failing to create a compatible stream for
    the html5 client
  * fix unnecessary xdg menu data in some subcommands
  * fix large xdg menu data causing initial packet size errors
  * fix packet size warning message format
  * fix start menu with python3 clients
  * fix html5 client connection error when xdg-menu data is
    missing
  * fix html5 client compatibility with buggy x264 encoders (as
    above)
  * fix html5 client clipboard packet format
  * fix session info graphs start values
  * fix colour channels swapped with some window icons and
    desktop servers
  * fix slower compression code path wrongly used when av-sync
    is disabled
  * fix icon type attribute (remove dot)
  * fix signal forwarding with python3 servers
  * fix system tray forwarding with python3 servers
  * fix socket attributes name lookup for xpra info
  * fix handling proxy server info requests
  * fix proxy server info errors trying to enumerate sessions
  * fix automatic MTU adjustements with UDP transport
  * fix NVENC compatiblity with library soname found in newer
    installers
  * fix invalid python2 DEB dependency in main meta package
  * fix default config value for opengl attribute
  * fix HTML5 client authentication issue when going through a
    proxy server
  * fix socket errors on startup with bind-ssl
  * fix server dbus service attribute accessor methods
  * fix network jitter injector
  * fix avahi mdns publisher test tool
  * fix zeroconf error when service info is not available
  * fix remote ssh failures with python3-only installations
  * fix automatic interpreter version switching when re-executing
  * fix start-via-proxy exit code handler
  * fix socket-permissions option not being honoured
  * fix error in the codec loader if the first codec attempted
    fails
  * fix error in the codec instantiation leak detection code
  * fix exit hooks not being called with 'exit-with-client'
  * fix RandR build errors with older versions of Cython (ie:
    Xenial)
  * fix GTK3 build of the keyboard test tool on MS Windows
  * fix errors parsing xresources
  * fix handling of xsettings with python3 servers
  * fix font hinting detection with python3
  * fix errors during cleanup if server initialization or
    startup had failed
  * fix pure python3 builds cairo headers used
  * updated package dependencies: recommend python-dns for sshfp
    support
* Fri Apr 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5.1
  * fix sending of icons as premultipled ARGB
  * fix compatibility with old versions of python-pillow
  * fix scroll encoding code flow (should be impossible to hit)
  * fix handling of info requests with Python3 servers
  * fix missing option for lock argument in man page
  * fix ssh errors handling authentication failures
  * fix ssh server connections and support 'none' authentication
  * fix start new command menu
  * fix appindicator failures when we fail to locate the default
    icon
  * fix command line tools usage under cygwin and terminal
    emulators
  * fix pointer position on multi-monitor shadow servers
  * fix system tray forwarding with python3 servers
  * fix window icons forwarding (MS Windows and MacOS mostly)
  * fix detection of splash window types
  * fix server startup errors when X11 root properties are
    invalid
  * fix shadow server startup failures on MacOS
  * fix system tray errors during shadow server startup on MacOS
  * fix printing errors with python3 builds and rencode packet
    encoder
  * fix parsing of printer options
  * fix dispatching of printer jobs to clients with python3
    servers
  * fix parsing of key symbol definitions with python3 servers
  * fix compatibility with older versions of GTK3
  * fix proxy video encoders initialization
  * fix 'missing encodings' server error with python3
  * fix spurious clipboard warning when clipboard is disabled
  * disable modal windows by default (was enabled by default
    since v2.3)
  * workaround buggy system trays
  * try harder to prevent hash collisions in scroll encoding
  * skip risky opengl probing when the initial check failed
  * prevent file conflicts with older packages
  * don't use appindicator with Fedora Gnome
  * minor packaging fixes (dates)
  * remove spurious ssh dnssec check logging
  * bump version in cups backend
* Tue Mar 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5
  * Python 3 port mostly complete
  * pixel compression and bandwidth management:
    + better recovery from network congestion
    + distinguish refresh from normal updates
    + better tuning for mmap connections
    + heuristics improvements
    + use video encoders more aggressively
    + prevent too many delayed frames with x264
    + better video region detection with opengl content
  * better automatic tuning for client applications
    + based on application categories
    + application supplied hints
    + application window encoding hints
    + using environment variables and disabling video
  * HTML5 client improvements
  * Client improvements:
    + make it easier to start new commands, provide start menu
    + probe OpenGL in a subprocess to detect and workaround
    driver crashes
    + use appindicator if available
  * Server improvements:
    + start command on last client exit
    + honour minimum window size
    + Python 3
    + upgrade-desktop subcommand
  * Network layer:
    + less copying
    + use our own websocket layer
    + make mmap group configurable
    + TCP CORK support on Linux
  * SSH transport:
    + support .ssh/config with paramiko backend
    + connecting via ssh proxy hosts
  * SSHFP with paramiko:
    + clipboard: restrict clipboard data transfers size
  * code cleanups, etc
- Removed python2-opengl requirement (package not available
  and unnecessary since this release)
- Refreshed xpra-paths.patch
* Fri Mar  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Enabled OpenGL (fixes boo#1127415)
- Added brotli as build requirement
- Refreshed xpra-paths.patch
* Thu Jan 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4.3
  * fix minor glib timer handle leak and unnecessary timer
    scheduling
  * fix keyboard backwards compatibility with older 1.0 servers
  * fix error in keyboard debug logging
  * fix h264 decoding in HTML5 client
  * fix session info and bug report windows not getting
    dismissed in HTML5 client
  * fix precise wheel motion events with HTML5 client
  * fix clipboard with MacOS GTK2 clients
  * fix swap-keys menu entry wrongly disabled
  * fix potential memory leaks and errors in codecs due to cast
    error
  * fix crashy codecs on MS Windows: disable x264, 32-bit vpx
    with large sizes
  * fix validation errors with some quality and speed control
    commands
  * fix buggy parsing of clipboard-contents packets
  * fix jpeg encoder and decoder library version requirements
    (ie: for CentOS 7.x)
  * fix starting sessions via ssh on Ubuntu (workaround buggy
    systemd-run)
  * fix MS Windows clients handling system tray icons without an
    alpha channel
  * fix error in video exception message formating
  * fix errors handling pointer events with extra relative
    pointer data
  * fix potential string substitution errors with python2
  * fix connection to hosts that resolve to ipv6 only addresses
  * fix dbus mixin attributes initialized twice (wrong values)
  * fix race condition error with network congestion events
  * fix compatibility with newer ArchLinux Xorg path
  * fix exec-auth module timeout not being honoured
  * fix exec-auth wrongly returning success on MacOS
  * workaround SSH errors with Windows Services for Linux
  * reduce impact of fullscreen and maxmimized attributes on
    window refresh rate
  * never lock the batch delay when mmap is enabled
* Wed Dec  5 2018 aloisio@gmx.com
- Update to version 2.4.2
  * fix server crash with application setting invalid X11 atoms
  * fix missing windows with some mono applications (ignore
    invalid X11 atoms)
  * fix small X11 memory leak
  * fix encoding of empty areas (hard to trigger)
  * fix client hangs due to signal-watcher (now disabled with
    python2)
  * fix virtual printer cleanup errors
  * fix leaking xvfb processes when displayfd times out
  * fix window size hints not being sanitized correctly
  * fix cpu waste and automatic quality calculations
  * fix statistics used by shadow servers
  * fix error capturing screenshots on MS Windows
  * fix logging error in modifier state change failure code path
  * fix nvenc errors with odd image heights
  * fix over aggressive screen update rectangle merging
  * fix race condition causing the connection cleanup code to
    run twice
  * fix ssh dialog button actions
  * ensure Qt applications use the X11 backend so we can
    intercept them
  * skip unnecessary video tests when mmap is enabled
  * handle property change handlers errors more gracefully
  * avoid recycling video contexts unnecessarily
  * don't flush video encoders when doing a regular content
    refresh
* Sun Nov  4 2018 Jan Engelhardt <jengelh@inai.de>
- Make xpra-html5 subpackage noarch
- Speed up find -exec
* Sun Nov  4 2018 Luigi Baldoni <aloisio@gmx.com>
- Dropped xpra-rpmlintrc
* Thu Nov  1 2018 aloisio@gmx.com
- Update to version 2.4.1
  * fix popup window focus for some Java applications
  * fix popup window focus issue (ie: xterm menu)
  * fix system tray errors when mmap is disabled
  * fix missing codecs (numpy was blocked from loading)
  * fix nvenc compatibility with more python / cython / OS
    versions
  * fix backwards compatibility in keyboard mapping
  * fix session info errors when connecting to older servers
  * fix man page typo
  * fix default value 'auto' for ssh option, better compatibility
  * fix dead code triggering some debug warnings
  * fix rare race condition when closing a connection
  * fix 'flush' client encoding options parsing
  * fix overzealous clipboard sanitization code
  * fix missing notification messages
  * fix ssh client authentication: try all keys found
  * fix version update check
  * fix usability issues with GTK3, especially on MS Windows
  * fix cython compilation warnings
  * avoid ethtool warning spam
  * use correct headers for building python3 cairo workaround
    module
* Tue Oct 30 2018 Luigi Baldoni <aloisio@gmx.com>
- Added python2-paramiko as recommended runtime dependency
- Spec cleanup
* Fri Oct 26 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4
  * SSH client integration (paramiko)
  * builtin server support for TCP socket upgrades to SSH
    (paramiko)
  * automatic TCP port allocation
  * expose desktop-sessions as VNC via mdns
  * add zeroconf backend
  * register more URL schemes
  * window content type heuristics configuration
  * use content type it to better tune automatic encoding
    selection
  * automatic video scaling
  * bandwidth-limit management in video encoders
  * HTML5 client mpeg1 and h264 decoding
  * HTML5 client support for forwarding of URL open requests
  * HTML5 client Internet Explorer 11 compatibility
  * HTML5 client toolbar improvements
  * HTML5 fullscreen mode support
  * limit video dimensions to cap CPU and bandwidth usage
  * keyboard layout handling fixes
  * better memory management and resource usage
  * new default GUI welcome screen
  * desktop file for starting shadow servers more easily
  * clipboard synchronization with multiple clients
  * use notifications bubbles for more important events
  * workarounds for running under Wayland with GTK3
  * modal windows enabled by default
  * support xdg base directory specification and socket file time
  * improved python3 support (still client only)
  * multi-window shadow servers on MacOS and MS Windows
  * buildbot upgrade
  * more reliable unit tests
  * fixes and workarounds for Java client applications
  * locally authenticated users can shutdown proxy servers
  * restrict potential privileged information leakage
  * enhanced per-client window filtering
  * remove extra pixel copy in opengl enabled client
  * clip pointer events to the actual window content size
  * new platforms: Ubuntu Cosmic, Fedora 29
- Refreshed xpra-paths.patch
- Spec cleanup
* Mon Oct  8 2018 aloisio@gmx.com
- Update to version 2.3.4
  * fix server does not shutdown cleanly (Xvfb not killed)
  * fix signals not emitted (ie: delay-tray command line option)
  * fix client desktop-scaling corner cases
  * fix handling of mixed clicks on system tray and the menu
    entries
  * fix MS Windows shadow server's cursor capture
  * fix URL parsing from launcher (ie: MacOS URL association)
  * fix MacOS crash with GTK3 builds and file chooser
  * fix non-opengl windows missing spinner with GTK3
  * fix RPM license information
  * fix mDNS zeroconf library version on MS Windows with Python 2
  * fix connection errors from making the client launcher exit
  * fix python3 errors in dbus server code
  * fix spurious error messages caused by video pipeline changes
  * fix proxy-video-encoders=all substitution
  * fix unicode string errors with RFB protocol and Python 3
  * fix missing idle and clipboard server information
  * fix .xpra file association with DEB packaging
  * fix pointer polling error with RFB connections (pointer
    going AWOL)
  * fix handling of closed RFB connections
  * fix unmanaged X11 call from shadow servers (potential
    crashes)
  * fix fallback pynotify notification handler
  * fix Python 3 shadow servers with RFB
  * fix Python 3 string errors writing run-xpra scripts
  * fix deadlocks with RFB connections
  * fix missing key mapping errors with RFB clients
  * fix session name not honoured or exposed via mdns for shadow
    servers
  * fix X11 display detection (socket may be owned by root with
    some display managers)
  * fix compatibility with csh and tcsh
  * fix spurious modifier key events from the HTML5 client
  * fix tray icon corruption on MS Windows
  * fix Motif WM hints parsing
  * fix DEB packaging dependencies
  * fix NVENC encoder wrongly exposing encodings which are not
    available
  * fix error running unit tests on MS Windows
  * fix potential file descriptor leak
  * fix valid XAuthority path potentially not found because
    unexpanded
  * fix proxy servers not honouring passwords in connection
    strings
  * fix sqlite authentication backend issue with identical
    usernames
  * support CUDA 10 and optimizations for Volta GPUs
  * Fedora 29 compatibility
  * fix race condition in unit tests which was causing random
    failures
  * add dependency required for running the unit tests with
    rpmbuild
  * prevent repeated clipboard warnings
  * let the server chooose the best initial quality to use
  * add file missing from clean build target
  * add missing entries in man page
  * add missing desktop file icons
  * shadow the current display if none is specified and we find
    more than one display
  * remove unneeded import, spurious debug logging
  * limit the amount of information exposed via the proxy
    server's dbus service
  * support base64 encoded SSL certificate data
  version 2.3.3
  * fix value shown in frame extents warning
  * fix HTML5 relative URLs for window control icons
  * fix HTML5 pointer events missing modifier keys
  * fix parsing errors when no display is specified
  * fix URL parsing with Python 3
  * fix tray setup errors on early client exit
  * fix putty plink PATH lookup issue
  * fix python3 compatibility for printer forwarding script
  * fix python3 alert box on MS Windows
  * fix python3 packaging on MS Windows
  * fix python3 client rendering of transparency with opengl
    disabled
  * fix file descriptor warnings on process exit with MS Windows
    builds
  * fix MS Windows monitor API overflow on 64-bit systems
  * fix compilation error with latest MSYS2 installations
  * fix desktop servers exit code
  * fix network congestion calculations when records expire
  * fix bandwidth warnings caused by slow client picture decoding
  * fix xpra info race condition error during cleanup
  * fix clipboard warnings: don't enable it unless the client
    requests it
  * fix spurious stacktraces caused by focus events on OR windows
  * fix painting of spinners with desktop-scaling and non-opengl
    backends
  * fix 'terminate server when command exits' from html5 client
  * fix SSL socket timeouts in proxy server
  * fix errors starting proxy instances if the user's home
    directory does not exist
  * fix ssh start remote command line compatibility mode
  * fix command line backwards compatibility
  * fix handling of tray geometry and keyboard detection failures
  * fix bandwidth-limit changes from the system tray menu
  * fix system version warnings on MacOS
  * force GTK3 Posix clients to use X11 backend (native Wayland
    crashes)
  * support cx_Freeze 5.x on MS Windows
  * don't require local user accounts with pam logins
  * drop invalid client connections without showing errors
    (desktop mode)
  * support building with Python 3.7 (some features made
    optional until ported over)
  * disable webcam forwarding with MS Windows client (broken
    upstream)
  * add missing RPM dependencies for running unit tests
  * prevent Python Pillow debug log spam
  * don't show spurious import errors during printing subsystem
    cleanup
  * show another possible reason for connection failures
  * make remote ssh command easier to parse
  * abort tests if build fails
  * use free colour profiles in all icon files
  * add missing man page entry for 'forward-xdg-open'
  * add missing files to manifest
  * man page typos
* Tue Jul 31 2018 jon@moozaad.co.uk
- added libsystemd build req to fix invalid /etc/default/xpra usage
* Wed Jul 18 2018 jon@moozaad.co.uk
- re-added xdummy args as auto detection wasn't enabling it
- reverted to python 2 for server support
- removed python 3 specific patch (cairo)
* Wed Jul 18 2018 jon@moozaad.co.uk
- switched to python3
- added webp support
- cleanup spec file of default build options
- now builds on Leap >= 42
- patched broken py3cairo detection
- Removed ffmpeg for <= Leap 15 (requires libav >= 58.18)
- Removed vpx for < Leap 15 (that leaves Leap 42.x with avcodec2 and webp)
* Wed Jul 18 2018 aloisio@gmx.com
- Update to version 2.3.2
  * fix notification actions support with shadow servers
  * fix paint errors with reformatted images using outdated
    stride value
  * fix control commands that call window refresh
  * fix broken pipe error when the browser cancels downloading
    the noicon placeholder
  * fix spurious refresh events
  * fix missing bug report data due to path errors
  * fix XAUTHORITY environment variable getting clobbered
  * fix html5 window refresh not throttled when the document is
    not visible
  * fix non-opengl painting of windows with a padding area
  * fix rgb paint of mmap data with the python2 cairo backend
  * fix invalid clipboard toggle requests not ignored
  * fix missing context handler for keymap setup (crash possible)
  * fix proxy server test to use a signal to stop the test
    instance
  * fix invalid exception value in X11 atom bindings
  * fix bandwidth limit client bypass and connection errors
  * fix building CUDA kernels with GCC 8.1
  * fix tray menu setup error when the clipboard is disabled
  * fix GTK3 buffer overflow with non-opengl backend
  * fix startup errors with pulseaudio if XDG_RUNTIME_DIR is
    missing
  * fix clipboard token send error when there are no targets
  * don't overwrite the dynamic system tray icon with the
    default one on startup
  * correctly disable desktop-scaling when mmap is enabled
  * skip repainting pointer overlay when the position is
    unchanged
  * prevent authenticated users from shutting down proxy servers
  * don't turn off notifications when we don't have a forwarder
    instance
  * don't try to log an exception that does not exist
  * allow the user to disable all video encoders and csc modules
  * send missing exception details to server with remote-logging
  * avoid RFB errors if screen capture fails
  * avoid further errors when shadow capture fails
  * recommend the dbus-x11 with the DEB package
  version 2.3.1:
  * fix CentOS / RHEL rpm dependencies for ldap authentication
  * fix spurious notifications warning
  * fix unsynced X11 context access to DPI (potential crash or
    warnings)
  * fix compilation warning in ffmpeg compatibility shim
  * fix filename extension check in launcher
  * fix h264 decoding in html5 client
  * fix menu stacking level in html5 client
  * fix focus issues with html5 client
  * fix socket error race condition during shutdown
  * fix scroll encoding errors on images with modified rowstride
  * fix desktop and shadow servers xinerama sizing issues
  * fix pixel encoding errors at low pixel depths
  * fix pixel-depth 8 wrongly rejected for start-desktop mode
  * fix colour encoding at pixel-depth 8
  * fix systemd warnings and packaging on Ubuntu 16.04
  * fix html5 client errors with audio debugging enabled
  * fix readonly mode bypass
  * fix client failure on servers without a valid desktop size
  * fix VNC connection handling of authentication
  * fix scary X11 desktop server warning with VNC clients
  * fix error in video debug logging
  * fix nvfbc errors during cleanup after initialization failures
  * fix client launcher not exiting on close
  * fix RFB clients causing sessions to be locked
  * fix rare deadlocks in exception handler
  * fix MacOS deprecation warnings
  * fix screen capture test script
  * fix CUDA DLL packaging
  * fix named-pipe errors with MS Windows Python3 and 64-bit
    builds
  * fix MinGW path detection issues
  * fix potential mmap leak with Python3 builds
  * fix screen update errors when XShm is disabled
  * silence GCC warnings when compiling NvFBC on MS Windows
  * increase default bandwidth congestion tolerance
  * remove duplicated DLLs from MS Windows Python3 builds
  * allow debugging via environment variables for all categories
  * don't prompt for the ssh password if we already have it
  * honour CFLAGS and LDFLAGS env vars
  * remove duplicated encoding from vpx encoder
  * add workaround for distributions shipping unpatched distutils
  * increase unit test failure timeout
  version 2.3:
  * stackable authentication modules
  * tcp wrappers authentication module
  * gss, kerberos, ldap and u2f authentication modules
  * request access to the session
  * pulseaudio server per session to prevent audio leaking
  * better network bandwidth utilization and congestion
    management
  * faster encoding and decoding: YUV for webp and jpeg, encoder
    hints, better vsync
  * notifications actions forwarding, custom icons, expose
    warnings
  * upload notification and management
  * shadow servers multi window mode
  * tighter client OS integratioin
  * client window positioning and multi-screen support
  * unique application icon used as tray icon
  * multi stop or attach
  * control start commands
  * forward signals sent to windows client side
  * forward requests to open URLs or files on the server side
  * html5 client improvements: top bar, debugging, etc
  * custom http headers, support content security policy
  * python3 port improvements
  * bug fixes: settings synchronization, macos keyboard mapping,
    etc
  * packaging: switch back to ffmpeg system libraries, support
    GTK3 on macos
  * structural improvements: refactoring, fewer synchronized X11
    calls, etc
  version 2.2:
  * support RFB clients (ie: VNC) with bind-rfb or rfb-upgrade
    options
  * UDP transport (experimental) with bind-udp and
    udp://host:port URLs
  * TCP sockets can be upgrade to Websockets and / or SSL, RFB
  * multiple bind options for all socket types supported: tcp,
    ssl, ws, wss, udp, rfb
  * bandwidth-limit option, support for very low bandwidth
    connections
  * detect network performance characteristics
  * "xpra sessions" browser tool for both mDNS and local sessions
  * support arbitrary resolutions with Xvfb (not with Xdummy yet)
  * new OpenGL backends, with support for GTK3 on most platforms
    and window transparency on MS Windows
  * optimized webp encoding, supported in HTML5 client
  * uinput virtual pointer device for supporting fine grained
    scrolling
  * connection strings now support the standard URI format
    protocol://host:port/
  * rencode is now used by default for the initial packet
  * skip sending audio packets when inactive
  * improved support for non-us keyboard layouts with non-X11
    clients
  * better modifier key support on Mac OS
  * clipboard support with GTK3
  * displayfd command line option
  * cosmetic system tray menu layout changes
  * dbus service for the system wide proxy server (stub)
  * move mmap file to $XDG_RUNTIME_DIR (where applicable)
  * password prompt dialog in client
  * fixed memory leaks
- Refreshed xpra-paths.patch
- Switched to ffmpeg4
* Fri Nov 10 2017 aloisio@gmx.com
- Update to version 2.1.3 (see NEWS)
- Refreshed xpra-paths.patch
* Wed Jul 26 2017 aloisio@gmx.com
- Update to version 2.1 (see NEWS)
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Wed Nov 12 2014 olaf@aepfle.de
- avoid republish after rebuild of unchanged sources
* Thu May 30 2013 pascal.bleser@opensuse.org
- update to 0.9.4
* Tue Apr 24 2012 pascal.bleser@opensuse.org
- initial version (0.2.0)
